import { defineComponent, reactive, ref } from 'vue';
import styles from './index.module.less';
import {
  NButton,
  NDatePicker,
  NForm,
  NFormItem,
  NSelect,
  NSpace,
  useMessage
} from 'naive-ui';
import { BOOK_DATA } from '/src/views/natural-resources/model/add-teaching';
import { classGroupPage, lessonTrainingAdd } from '../../../api';
import dayjs from 'dayjs';

export default defineComponent({
  name: 'assign-homework',
  props: {
    /** 初始数据 */
    trainList: {
      type: Array,
      default: () => []
    }
  },
  emits: ['close', 'confirm'],
  setup(props, { emit }) {
    const message = useMessage();

    const forms = reactive({
      currentTime: dayjs(dayjs().format('YYYY-MM-DD')).valueOf(),
      id: null as any,
      uploading: false,
      classList: [] as any,
      currentGradeNum: null,
      expireDate: dayjs().add(7, 'day').format('YYYY-MM-DD') as any, // 默认7天
      classGroupId: null as any
    });
    const formsRef = ref();

    const getClassList = async () => {
      try {
        const { data } = await classGroupPage({
          currentGradeNum: forms.currentGradeNum,
          page: 1,
          rows: 99
        });
        const temp = data.rows || [];
        const classList = [] as any;
        temp.forEach((row: any) => {
          classList.push({
            label: row.currentClass + '班',
            value: row.id
          });
        });

        forms.classList = classList;
      } catch {
        //
      }
    };
    const onSubmit = async () => {
      formsRef.value?.validate(async (err: any) => {
        if (err) {
          return;
        }
        forms.uploading = true;
        try {
          const trainList = props.trainList || [];
          const details: any[] = [];
          trainList.forEach((item: any) => {
            details.push({
              trainingType: item.trainingType,
              musicId: item.musicId,
              trainingConfigJsonObject: item.trainingConfigJson
            });
          });
          const params = {
            lessonTrainingDetails: details,
            expireDate: forms.expireDate + ' 23:59:59',
            classGroupId: forms.classGroupId
          };
          await lessonTrainingAdd(params);
          message.success('布置成功');
          emit('close');
        } catch {
          //
        }
        forms.uploading = false;
      });
    };

    return () => (
      <div class={styles.assignHomeworkContainer}>
        <NForm
          ref={formsRef}
          model={forms}
          labelAlign="right"
          labelWidth={'auto'}
          labelPlacement="left">
          <NFormItem
            label="年级"
            path="currentGradeNum"
            rule={[
              {
                required: true,
                message: '请选择年级',
                trigger: 'change',
                type: 'number'
              }
            ]}>
            <NSelect
              v-model:value={forms.currentGradeNum}
              placeholder="请选择年级"
              options={BOOK_DATA.grades}
              clearable
              onUpdate:value={() => {
                forms.classGroupId = null;
                getClassList();
              }}
            />
          </NFormItem>
          <NFormItem
            label="班级"
            path="classGroupId"
            rule={[
              { required: true, message: '请选择班级', trigger: 'change' }
            ]}>
            <NSelect
              v-model:value={forms.classGroupId}
              placeholder="请选择班级"
              clearable
              options={forms.classList}
            />
          </NFormItem>
          <NFormItem
            label="截止日期"
            path="expireDate"
            rule={[
              { required: true, message: '请选择截止日期', trigger: 'change' }
            ]}>
            <NDatePicker
              v-model:formatted-value={forms.expireDate}
              type="date"
              clearable
              valueFormat="yyyy-MM-dd"
              style={{ width: '100%' }}
              isDateDisabled={(ts: number) => {
                return ts < forms.currentTime;
              }}
            />
          </NFormItem>

          <NSpace class={styles.updateBtnGroup}>
            <NButton strong type="default" round onClick={() => emit('close')}>
              取消
            </NButton>
            <NButton
              strong
              type="primary"
              round
              disabled={forms.uploading}
              loading={forms.uploading}
              onClick={onSubmit}>
              确认
            </NButton>
          </NSpace>
        </NForm>
      </div>
    );
  }
});
